Author: tfmorris
Date: 2007-11-25 16:31:27-0800
New Revision: 13842
Modified:
trunk/src_new/org/argouml/cognitive/ListSet.java
trunk/src_new/org/argouml/cognitive/ToDoItem.java
trunk/src_new/org/argouml/cognitive/ToDoList.java
trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java
trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java
trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java
trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java
trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java
trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java
trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java
trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java
trunk/src_new/org/argouml/persistence/TodoParser.java
trunk/src_new/org/argouml/ui/DisplayTextTree.java
trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java
trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java
trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java
trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java
trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java
trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java
trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java
trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java
trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java
trunk/src_new/org/argouml/uml/reveng/java/Modeller.java
trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java
trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java
trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java
Log:
Update Javadoc references to vectors to match implementation.
Remove unused imports. No other code changes.
Modified: trunk/src_new/org/argouml/cognitive/ListSet.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ListSet.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ListSet.java&p2=trunk/src_new/org/argouml/cognitive/ListSet.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ListSet.java (original)
+++ trunk/src_new/org/argouml/cognitive/ListSet.java 2007-11-25 16:31:27-0800
@@ -67,7 +67,7 @@
/**
* The constructor.
*
- * @param n the initial capacity of the vector
+ * @param n the initial capacity of the ListSet
*/
public ListSet(int n) {
list = new ArrayList<T>(n);
Modified: trunk/src_new/org/argouml/cognitive/ToDoItem.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ToDoItem.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ToDoItem.java&p2=trunk/src_new/org/argouml/cognitive/ToDoItem.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ToDoItem.java (original)
+++ trunk/src_new/org/argouml/cognitive/ToDoItem.java 2007-11-25 16:31:27-0800
@@ -440,7 +440,7 @@
return false;
}
- // For some reason VectorSet.equals() allocates a lot of memory, well
+ // For some reason ListSet.equals() allocates a lot of memory, well
// some memory at least. Lets try to avoid that when not needed by
// invoking this test only when the two previous tests are not decisive.
if (!getOffenders().equals(i.getOffenders())) {
Modified: trunk/src_new/org/argouml/cognitive/ToDoList.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ToDoList.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ToDoList.java&p2=trunk/src_new/org/argouml/cognitive/ToDoList.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ToDoList.java (original)
+++ trunk/src_new/org/argouml/cognitive/ToDoList.java 2007-11-25 16:31:27-0800
@@ -474,7 +474,7 @@
/**
* @param item the todo item to be removed
* @return <code>true</code> if the argument was a component of this
- * vector; <code>false</code> otherwise
+ * list; <code>false</code> otherwise
*/
private synchronized boolean removeE(ToDoItem item) {
boolean res = items.remove(item);
@@ -484,7 +484,7 @@
/**
* @param item the todo item to be removed
* @return <code>true</code> if the argument was a component of this
- * vector; <code>false</code> otherwise
+ * list; <code>false</code> otherwise
*/
public boolean removeElement(ToDoItem item) {
boolean res = removeE(item);
@@ -498,7 +498,7 @@
/**
* @param item the todo item to be resolved
* @return <code>true</code> if the argument was a component of this
- * vector; <code>false</code> otherwise
+ * list; <code>false</code> otherwise
*/
public boolean resolve(ToDoItem item) {
boolean res = removeE(item);
@@ -510,7 +510,7 @@
* @param item the todo item
* @param reason the reason TODO: Use it!
* @return <code>true</code> if the argument was a component of this
- * vector; <code>false</code> otherwise
+ * list; <code>false</code> otherwise
* @throws UnresolvableException unable to resolve
*/
public boolean explicitlyResolve(ToDoItem item, String reason)
Modified: trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java&p2=trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java (original)
+++ trunk/src_new/org/argouml/cognitive/ui/GoListToDecisionsToItems.java 2007-11-25 16:31:27-0800
@@ -109,7 +109,7 @@
return getDecisionList().indexOf(child);
}
if (parent instanceof Decision) {
- // instead of makning a new vector, decrement index, return when
+ // instead of making a new list, decrement index, return when
// found and index == 0
List<ToDoItem> candidates = new ArrayList<ToDoItem>();
Decision dec = (Decision) parent;
Modified: trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java&p2=trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java (original)
+++ trunk/src_new/org/argouml/cognitive/ui/GoListToGoalsToItems.java 2007-11-25 16:31:27-0800
@@ -94,7 +94,7 @@
return getGoalList().indexOf(child);
}
if (parent instanceof Goal) {
- // instead of makning a new vector, decrement index, return when
+ // instead of making a new list, decrement index, return when
// found and index == 0
List<ToDoItem> candidates = new ArrayList<ToDoItem>();
Goal g = (Goal) parent;
Modified: trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java&p2=trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java (original)
+++ trunk/src_new/org/argouml/cognitive/ui/GoListToTypeToItem.java 2007-11-25 16:31:27-0800
@@ -94,7 +94,7 @@
return KnowledgeTypeNode.getTypeList().indexOf(child);
}
if (parent instanceof KnowledgeTypeNode) {
- // instead of makning a new vector, decrement index, return when
+ // instead of making a new list, decrement index, return when
// found and index == 0
List<ToDoItem> candidates = new ArrayList<ToDoItem>();
KnowledgeTypeNode ktn = (KnowledgeTypeNode) parent;
Modified: trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java&p2=trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java (original)
+++ trunk/src_new/org/argouml/cognitive/ui/ToDoPane.java 2007-11-25 16:31:27-0800
@@ -111,7 +111,7 @@
private JComboBox combo;
/**
- * Vector of TreeModels.
+ * List of TreeModels.
*/
private List<ToDoPerspective> perspectives;
private ToDoPerspective curPerspective;
@@ -521,7 +521,7 @@
ToDoPerspective poster = new ToDoByPoster();
ToDoPerspective type = new ToDoByType();
- // add the perspetives to a vector for the combobox
+ // add the perspectives to a list for the combobox
List<ToDoPerspective> perspectives = new ArrayList<ToDoPerspective>();
perspectives.add(priority);
Modified: trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java&p2=trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java (original)
+++ trunk/src_new/org/argouml/language/java/generator/CodePieceCollector.java 2007-11-25 16:31:27-0800
@@ -62,7 +62,7 @@
/**
The parser adds a code piece here. The code pieces will be
- inserted in sorted order in the codePieces vector.
+ inserted in sorted order in the codePieces list.
@param codePiece A named code piece found in the code.
*/
Modified: trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java&p2=trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java (original)
+++ trunk/src_new/org/argouml/language/java/generator/OperationCodePiece.java 2007-11-25 16:31:27-0800
@@ -110,7 +110,7 @@
* java.io.BufferedReader, java.io.BufferedWriter, java.util.Stack)
*
* Write the code this piece represents to file. Remove this
- * feature from the top vector in the stack newFeaturesStack.
+ * feature from the top list in the stack newFeaturesStack.
*/
public void write (BufferedReader reader,
BufferedWriter writer,
Modified: trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java&p2=trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java (original)
+++ trunk/src_new/org/argouml/notation/providers/uml/NotationUtilityUml.java 2007-11-25 16:31:27-0800
@@ -63,7 +63,7 @@
static PropertySpecialString[] operationSpecialStrings;
/**
- * The vector of CustomSeparators to use when tokenizing attributes.
+ * The List of CustomSeparators to use when tokenizing attributes.
*/
static final List<CustomSeparator> operationCustomSep;
Modified: trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java&p2=trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java (original)
+++ trunk/src_new/org/argouml/notation/providers/uml/OperationNotationUml.java 2007-11-25 16:31:27-0800
@@ -377,8 +377,8 @@
* Parse tokens following an open brace (properties).
*
* @param st tokenizer being used
- * @param properties current properties vector
- * @return updated vector of properties
+ * @param properties current properties list
+ * @return updated list of properties
* @throws ParseException
*/
private List<String> tokenOpenBrace(MyTokenizer st, List<String> properties)
Modified: trunk/src_new/org/argouml/persistence/TodoParser.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/persistence/TodoParser.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/persistence/TodoParser.java&p2=trunk/src_new/org/argouml/persistence/TodoParser.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/persistence/TodoParser.java (original)
+++ trunk/src_new/org/argouml/persistence/TodoParser.java 2007-11-25 16:31:27-0800
@@ -77,7 +77,7 @@
private String critic;
/**
- * The offenders vector of the ResolvedCritic currently being
+ * The offenders list of the ResolvedCritic currently being
* read.
*/
private List offenders;
Modified: trunk/src_new/org/argouml/ui/DisplayTextTree.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/ui/DisplayTextTree.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/ui/DisplayTextTree.java&p2=trunk/src_new/org/argouml/ui/DisplayTextTree.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/ui/DisplayTextTree.java (original)
+++ trunk/src_new/org/argouml/ui/DisplayTextTree.java 2007-11-25 16:31:27-0800
@@ -406,7 +406,7 @@
/**
* Called in reexpand().
*
- * @return a Vector containing all expanded paths
+ * @return a List containing all expanded paths
*/
protected List<TreePath> getExpandedPaths() {
Modified: trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java&p2=trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java (original)
+++ trunk/src_new/org/argouml/ui/cmd/CmdSetPreferredSize.java 2007-11-25 16:31:27-0800
@@ -26,15 +26,15 @@
import java.util.ArrayList;
import java.util.List;
-import java.util.Vector;
-import org.argouml.i18n.Translator;
import org.tigris.gef.base.Cmd;
import org.tigris.gef.base.Editor;
import org.tigris.gef.base.Globals;
import org.tigris.gef.base.SelectionManager;
import org.tigris.gef.presentation.Fig;
+import org.argouml.i18n.Translator;
+
/**
* A command to set selected figs to their minimum size. <p>
Modified: trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java&p2=trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java (original)
+++ trunk/src_new/org/argouml/ui/explorer/rules/GoStimulusToAction.java 2007-11-25 16:31:27-0800
@@ -29,7 +29,6 @@
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
-import java.util.Vector;
import org.argouml.i18n.Translator;
import org.argouml.model.Model;
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrClassWithoutComponent.java 2007-11-25 16:31:27-0800
@@ -90,7 +90,7 @@
/**
* If there are classes that are not inside a component
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigClasses with no
* enclosing FigComponent
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrCompInstanceWithoutNode.java 2007-11-25 16:31:27-0800
@@ -91,7 +91,7 @@
/**
* If there are component-instances that have no enclosing FigMNodeInstance
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigComponentInstances with no
* enclosing FigMNodeInstance
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentInstanceWithoutClassifier.java 2007-11-25 16:31:27-0800
@@ -96,7 +96,7 @@
/**
* If there are component-instances that have no enclosing FigMNodeInstance
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigComponentInstances with no
* enclosing FigMNodeInstance
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrComponentWithoutNode.java 2007-11-25 16:31:27-0800
@@ -92,7 +92,7 @@
/**
* If there are components that have no enclosing FigMNode
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigComponents with no
* enclosing FigMNode
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrDupRoleNames.java 2007-11-25 16:31:27-0800
@@ -79,9 +79,9 @@
* that an association role is more tightly constrained than its
* parent.</p>
*
- * <p>Then loop through the ends, building a vector of end names that we
+ * <p>Then loop through the ends, building a list of end names that we
* have seen, and looking to see if the current end is already in that
- * vector. We ignore any ends that are unnamed, or have the empty string
+ * list. We ignore any ends that are unnamed, or have the empty string
* as name.</p>
*
* <p>Whilst this is an O(n^2) algorithm, most associations have only two
@@ -128,7 +128,7 @@
continue;
}
- // Is the name already in the vector of those seen, if not add it
+ // Is the name already in the list of those seen, if not add it
// and go on round.
if (namesSeen.contains(name)) {
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrInstanceWithoutClassifier.java 2007-11-25 16:31:27-0800
@@ -90,7 +90,7 @@
/**
* If there are instances that have no classifiers they belong to
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigObjects, FigComponentInstances
* and FigMNodeInstances with no classifier.
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrInterfaceWithoutComponent.java 2007-11-25 16:31:27-0800
@@ -91,7 +91,7 @@
/**
* If there are interfaces that are not inside a component
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigInterfaces with no
* enclosing FigComponent
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrNodeInsideElement.java 2007-11-25 16:31:27-0800
@@ -98,7 +98,7 @@
/**
* If there are nodes that have an enclosing Fig
- * the returned vector-set is not null. Then in the vector-set
+ * the returned ListSet is not null. Then in the ListSet
* are the UMLDeploymentDiagram and all FigMNodes with an
* enclosing Fig
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/CrOperNameConflict.java 2007-11-25 16:31:27-0800
@@ -97,7 +97,7 @@
*
* This algorithm is quadratic in the number of operations. If
* this became a problem, we would have to consider sorting the
- * operations vector and comparing only adjacent pairs
+ * operations list and comparing only adjacent pairs
* (potentially O(n log n) performance).<p>
*
* @param dm the {@link Object} to be checked against the critic.
@@ -119,8 +119,8 @@
// Get all the features (giving up if there are none). Then loop
// through finding all operations. Each time we find one, we compare
- // its signature with all previous (held in vector operSeen), and then
- // if it doesn't match add it to the vector.
+ // its signature with all previous (held in collection operSeen), and then
+ // if it doesn't match add it to the collection.
Collection operSeen = new ArrayList();
for (Object op : Model.getFacade().getOperations(dm)) {
@@ -133,7 +133,7 @@
}
}
- // Add to the vector and round to look at the next one
+ // Add to the collection and round to look at the next one
operSeen.add(op);
}
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/WizAssocComposite.java 2007-11-25 16:31:27-0800
@@ -27,11 +27,11 @@
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
-//import java.util.Vector;
import javax.swing.JPanel;
import org.apache.log4j.Logger;
+
import org.argouml.cognitive.ui.WizStepChoice;
import org.argouml.i18n.Translator;
import org.argouml.model.Model;
@@ -117,7 +117,7 @@
}
/**
- * Returns a vector of options to be used in creating a {@link
+ * Returns a list of options to be used in creating a {@link
* WizStepChoice} that will exercise the options.
* <p>
*
@@ -216,7 +216,7 @@
* (<code>_step1Choice</code>) for subsequent use.
* <p>
* <em>Note</em>. If the association has been deleted, then we may not be
- * able to create a vector of options. Under these circumstances we also
+ * able to create a list of options. Under these circumstances we also
* return null.
* <p>
*
Modified: trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java&p2=trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java (original)
+++ trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java 2007-11-25 16:31:27-0800
@@ -162,8 +162,8 @@
/**
* Version of the clone to ensure all sub-figs are copied.<p>
*
- * Uses the generic superclass clone which gives a vector of all the
- * figs. Then initialize our instance variables from this vector.<p>
+ * Uses the generic superclass clone which gives a list of all the
+ * figs. Then initialize our instance variables from this list.<p>
*
* @return A new copy of the the current fig.
*/
Modified: trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java&p2=trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java (original)
+++ trunk/src_new/org/argouml/uml/diagram/static_structure/ui/FigClassifierBox.java 2007-11-25 16:31:27-0800
@@ -169,8 +169,7 @@
}
/**
- * @return The vector of graphics for operations (if any).
- * First one is the rectangle for the entire operations box.
+ * @return The Fig for the operations compartment
*/
protected FigOperationsCompartment getOperationsFig() {
return operationsFig;
Modified: trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java&p2=trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java (original)
+++ trunk/src_new/org/argouml/uml/diagram/use_case/UseCaseDiagramGraphModel.java 2007-11-25 16:31:27-0800
@@ -69,7 +69,7 @@
* @param nodeOrEdge A model element, for whom the list of ports is
* wanted.
*
- * @return A vector of the ports found.
+ * @return A List of the ports found.
*/
public List getPorts(Object nodeOrEdge) {
if (Model.getFacade().isAActor(nodeOrEdge)) {
@@ -110,7 +110,7 @@
*
* @param port The port for which we want to know the incoming edges.
*
- * @return A vector of objects which are the incoming edges.
+ * @return A list of objects which are the incoming edges.
*/
public List getInEdges(Object port) {
if (Model.getFacade().isAActor(port)
@@ -134,12 +134,12 @@
*
* <em>Needs more work</em>. This would seem superficially to be
* identical to {@link #getInEdges}, but in our implementation we
- * return an empty vector.<p>
+ * return an empty list.<p>
*
* @param port The port for which we want to know the outgoing edges.
*
- * @return A vector of objects which are the outgoing edges. Currently
- * return the empty vector.
+ * @return A list of objects which are the outgoing edges. Currently
+ * return the empty list.
*/
public List getOutEdges(Object port) {
return Collections.EMPTY_LIST;
@@ -518,7 +518,7 @@
// Only interested in the "ownedElement" property. Either something has
// been added to the namespace for this model, or removed. In the
// latter case the "something" will be in the old value of the
- // property, which is the vector of owned elements, and the new value
+ // property, which is the collection of owned elements, and the new value
// will be the element import describing the model element and the
// model from which it was removed
Modified: trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java&p2=trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java (original)
+++ trunk/src_new/org/argouml/uml/diagram/use_case/ui/FigUseCase.java 2007-11-25 16:31:27-0800
@@ -234,7 +234,7 @@
epBigPort.setLineWidth(0);
epBigPort.setVisible(false);
- // The group for the extension points. The first entry in the vector
+ // The group for the extension points. The first entry in the group
// is the overall surrounding box itself. The group is not filled, nor
// has any line. The first entry we add is the epBigPort
@@ -344,9 +344,9 @@
/**
* Make a copy of the current fig.<p>
*
- * Uses the generic superclass clone which gives a vector of all
+ * Uses the generic superclass clone which gives a list of all
* the figs. Then initialize our instance variables from this
- * vector.<p>
+ * list.<p>
*
* @return A new copy of the the current fig.
*/
@@ -1085,7 +1085,7 @@
*/
private CompartmentFigText unhighlight() {
- // Loop through the vector of extension points, until we find a
+ // Loop through the list of extension points, until we find a
// highlighted one.
for (CompartmentFigText ft : getEPFigs()) {
if (ft.isHighlighted()) {
Modified: trunk/src_new/org/argouml/uml/reveng/java/Modeller.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/reveng/java/Modeller.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/reveng/java/Modeller.java&p2=trunk/src_new/org/argouml/uml/reveng/java/Modeller.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/reveng/java/Modeller.java (original)
+++ trunk/src_new/org/argouml/uml/reveng/java/Modeller.java 2007-11-25 16:31:27-0800
@@ -996,7 +996,7 @@
* @param name
* The name of the operation as a string
* @param parameters
- * A number of vectors, each representing a parameter.
+ * A number of lists, each representing a parameter.
* @param javadoc
* The javadoc comment. null or "" if no comment available.
* @param forceIt
@@ -2117,7 +2117,7 @@
/**
* Get collection of method calls.
- * @return vector containing collected method calls
+ * @return list containing collected method calls
*/
public synchronized List<String> getMethodCalls() {
return methodCalls;
Modified: trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java&p2=trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java (original)
+++ trunk/src_new/org/argouml/uml/ui/AbstractActionAddModelElement2.java 2007-11-25 16:31:27-0800
@@ -91,7 +91,7 @@
* depicted on the left side of the UMLAddDialog (sorry Arabic users) and
* can be moved via the buttons on the dialog to the right side. On the
* right side are the selected modelelements.
- * @return Vector
+ * @return List of choices
*/
protected abstract List getChoices();
Modified: trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java&p2=trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java (original)
+++ trunk/src_new/org/argouml/uml/ui/behavior/activity_graphs/PropPanelClassifierInState.java 2007-11-25 16:31:27-0800
@@ -263,9 +263,6 @@
setMultiSelect(true);
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#doIt(java.util.Vector)
- */
protected void doIt(Collection selected) {
Object cis = getTarget();
if (Model.getFacade().isAClassifierInState(cis)) {
@@ -273,9 +270,7 @@
}
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getChoices()
- */
+
protected List getChoices() {
List ret = new ArrayList();
Object cis = getTarget();
@@ -288,16 +283,12 @@
return ret;
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getDialogTitle()
- */
+
protected String getDialogTitle() {
return Translator.localize("dialog.title.add-state");
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getSelected()
- */
+
protected List getSelected() {
Object cis = getTarget();
if (Model.getFacade().isAClassifierInState(cis)) {
Modified: trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java&p2=trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java&r1=13841&r2=13842
==============================================================================
--- trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java (original)
+++ trunk/src_new/org/argouml/uml/ui/foundation/core/ActionAddAssociationSpecification.java 2007-11-25 16:31:27-0800
@@ -51,16 +51,12 @@
super();
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#doIt(java.util.Vector)
- */
+
protected void doIt(Collection selected) {
Model.getCoreHelper().setSpecifications(getTarget(), selected);
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getChoices()
- */
+
protected List getChoices() {
List ret = new ArrayList();
if (getTarget() != null) {
@@ -73,16 +69,12 @@
return ret;
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getDialogTitle()
- */
+
protected String getDialogTitle() {
return Translator.localize("dialog.title.add-specifications");
}
- /*
- * @see org.argouml.uml.ui.AbstractActionAddModelElement#getSelected()
- */
+
protected List getSelected() {
List ret = new ArrayList();
ret.addAll(Model.getFacade().getSpecifications(getTarget()));
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.
--- trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java (original)
+++ trunk/src_new/org/argouml/uml/cognitive/critics/WizManyNames.java 2007-11-25 16:31:27-0800
@@ -54,7 +54,7 @@
.localize("critics.WizManyNames-ins");
/**
* A vector of model elements.
*/
private List mes;
@@ -87,7 +87,7 @@
for (int i = 0; i < 3 && i < mSize; ++i) {
if (!Model.getFacade().isAModelElement(elements.get(i))) {
throw new IllegalArgumentException(
- "The vector should contain model elements in "
+ "The list should contain model elements in "
+ "the first 3 positions");
}
}
Modified: trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java
@@ -54,7 +54,7 @@
.localize("critics.WizManyNames-ins");
/**
- * A vector of model elements.
+ * A list of model elements.
*/
private List mes;
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java?view=diff&rev=13842&p1=trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java&p2=trunk/src_new/org/argouml/uml/diagram/collaboration/ui/FigClassifierRole.java&r1=13841&r2=13842
==============================================================================